@@ -92,6 +92,13 @@ class RegexURLPattern(urlresolvers.RegexURLPattern):
         self.default_args = default_args or {}
         self.name = name
 
+    def add_prefix(self, prefix):
+        """
+        Adds the prefix string to a string-based callback.
+        """
+        if prefix and isinstance(self._callback, basestring):
+            self._callback = '%s.%s' % (prefix, self._callback)
+
     @cached_property
     def callback(self):
         """
